jsTree v.1.0 - themes documentation

# jsTree v.1.0 - themes plugin

## Description

The `themes` plugin controls the looks of jstree - without this plugin you will get a functional tree, but it will look just like an ordinary UL list.

## Configuration

### theme

A string. Default is `"default"`.

The name of the theme to use to style the tree.

### url

A string (or `false` if not used). Default is `false`.

The location of the theme's CSS file, if set to `false` jstree will look for the file in `< theme folder >/themes/< theme name >/style.css`. You can set the theme folder using `$.jstree._themes = "PATH/TO/FOLDER/";`, otherwise it is autodetected as `<jquery.tree.js location>/themes/`.

### dots

A Boolean. Default is `true`.

Whether to show the connecting dots or not.

### icons

A Boolean. Default is `true`.

Whether to show the node icons or not.

## Demos

### Using the themes plugin

- Root node 1
  - Child node 1
  - Child node 2
- Root node 2

## API

### .set_theme ( name , url )

Set the tree's theme. Triggers an event.

- `string` name

  The name of the theme to use to style the tree.

- `string` url

  The location of the theme's CSS file, if omitted jstree will look for the file in:
  `< theme folder >/themes/< name >/style.css`.
  You can set the theme folder using:
  `$.jstree._themes = "PATH/TO/FOLDER/";`, otherwise it is autodetected as `<jquery.tree.js location>/themes/`.

### .get_theme ( )

Returns the name of the currently active theme.

### .show_dots ( ), .hide_dots ( ), .toggle_dots ( )

Show, hide or toggle the visibility of the dots connecting the tree's nodes.

### .show_icons ( ), .hide_icons ( ), .toggle_icons ( )

Show, hide or toggle the visibility of the icons next to the title of each the tree node.